<?php
/*
  Plugin Name: Visarzo Core
  Plugin URI: http://smartdatasoft.com/
  Description: Helping for the Visarzo theme.
  Author: SmartDataSoft
  Version: 1.6
  Author URI: http://smartdatasoft.com/
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

require_once __DIR__ . '/share/share-function.php';
require_once __DIR__ . '/vendor/autoload.php';
require_once __DIR__ . '/rating/ask_rating.php';

/**
 * The main plugin class
 */
final class Visarzo_Helper {

	/**
	 * Plugin version
	 *
	 * @var string
	 */
	const version = '1.6';


	/**
	 * Plugin Version
	 *
	 * @since 1.2.0
	 * @var   string The plugin version.
	 */
	const VERSION = '1.6';

	/**
	 * Minimum Elementor Version
	 *
	 * @since 1.2.0
	 * @var   string Minimum Elementor version required to run the plugin.
	 */
	const MINIMUM_ELEMENTOR_VERSION = '2.0.0';

	/**
	 * Minimum PHP Version
	 *
	 * @since 1.2.0
	 * @var   string Minimum PHP version required to run the plugin.
	 */
	const MINIMUM_PHP_VERSION = '7.0';

	/**
	 * Constructor
	 *
	 * @since  1.0.0
	 * @access public
	 */

	/**
	 * Class construcotr
	 */
	private function __construct() {
		$this->define_constants();
		register_activation_hook( __FILE__, array( $this, 'activate' ) );
		add_action( 'plugins_loaded', array( $this, 'init_plugin' ) );
	}

	/**
	 * Initializes a singleton instance
	 *
	 * @return \visarzo
	 */
	public static function init() {
		static $instance = false;

		if ( ! $instance ) {
			$instance = new self();
		}

		return $instance;
	}


	/**
	 * Define the required plugin constants
	 *
	 * @return void
	 */
	public function define_constants() {
		define( 'VISARZO_CORE_VERSION', self::version );
		define( 'VISARZO_CORE_FILE', __FILE__ );
		define( 'VISARZO_CORE_PATH', __DIR__ );
		define( 'VISARZO_CORE_URL', plugin_dir_url( __FILE__ ) );
		define( 'VISARZO_CORE_ASSETS', VISARZO_CORE_URL . '/assets' );
		$theme = wp_get_theme();
		define( 'THEME_VERSION_CORE', $theme->Version );
	}

	/**
	 * Initialize the plugin
	 *
	 * @return void
	 */
	public function init_plugin() {
		$this->checkElementor();
		load_plugin_textdomain( 'visarzo-core', false, basename( dirname( __FILE__ ) ) . '/languages' );
		new Visarzo\Helper\Posttype();
		// sidebar generator
		new \Visarzo\Helper\Sidebar_Generator();

		new \Visarzo\Helper\Widgets();
		if ( did_action( 'elementor/loaded' ) ) {
			new \Visarzo\Helper\Elementor();
		}

		if ( is_admin() ) {
			new \Visarzo\Helper\Admin();
		}
	}

	public function checkElementor() {
		// Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', array( $this, 'admin_notice_missing_main_plugin' ) );
			return;
		}

		// Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', array( $this, 'admin_notice_minimum_elementor_version' ) );
			return;
		}

		// Check for required PHP version
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', array( $this, 'admin_notice_minimum_php_version' ) );
			return;
		}
	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have Elementor installed or activated.
	 *
	 * @since  1.0.0
	 * @access public
	 */
	public function admin_notice_missing_main_plugin() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = '<p>If you want to use Elementor Version of "<strong>visarzo</strong>" Theme, Its requires "<strong>Elementor</strong>" to be installed and activated.</p>';

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required Elementor version.
	 *
	 * @since  1.0.0
	 * @access public
	 */
	public function admin_notice_minimum_elementor_version() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
		/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'elementor-hello-world' ),
			'<strong>' . esc_html__( 'Elementor ChildIt', 'elementor-hello-world' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'elementor-hello-world' ) . '</strong>',
			self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required PHP version.
	 *
	 * @since  1.0.0
	 * @access public
	 */
	public function admin_notice_minimum_php_version() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
		/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'visarzo-core' ),
			'<strong>' . esc_html__( 'Elementor ChildIt', 'visarzo-core' ) . '</strong>',
			'<strong>' . esc_html__( 'PHP', 'visarzo-core' ) . '</strong>',
			self::MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}


	/**
	 * Do stuff upon plugin activation
	 *
	 * @return void
	 */
	public function activate() {
		$installer = new Visarzo\Helper\Installer();
		$installer->run();
	}
}

/**
 * Initializes the main plugin
 *
 * @return \visarzo
 */
function visarzoCore() {
	return Visarzo_Helper::init();
}

// kick-off the plugin
visarzoCore();

register_sidebar(
	array(
		'name'          => esc_html__( 'Service Sidebar', 'visarzo' ),
		'id'            => 'sidebar-2',
		'description'   => esc_html__( 'Add widgets here.', 'visarzo' ),
		'before_widget' => '<div id="%1$s" class="base-sidebar %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="widget-title"><h3>',
		'after_title'   => '</h3></div>',
	)
);
register_sidebar(
	array(
		'name'          => esc_html__( 'Coaching Sidebar', 'visarzo' ),
		'id'            => 'sidebar-3',
		'description'   => esc_html__( 'Add widgets here.', 'visarzo' ),
		'before_widget' => '<div id="%1$s" class="base-sidebar %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="widget-title"><h3>',
		'after_title'   => '</h3></div>',
	)
);

// Hook called when the plugin is activated.
add_action( 'plugins_loaded', 'visarzo_function_elem_cpt_support' );
function visarzo_function_elem_cpt_support() {
	$cpt_support = get_option( 'elementor_cpt_support' );
	if ( ! $cpt_support ) {
		// First check if the option is not available already in the database. It not then create the array with all default post types including yours and save the settings.
		$cpt_support = array( 'page', 'post', 'service', 'coachings', 'Landing Pages' );
		update_option( 'elementor_cpt_support', $cpt_support );
	} elseif ( ! in_array( 'service', $cpt_support ) ) {
		// If the option is available then just append the array and update the settings.
		$cpt_support[] = 'service';
		update_option( 'elementor_cpt_support', $cpt_support );
	} elseif ( ! in_array( 'coachings', $cpt_support ) ) {
		// If the option is available then just append the array and update the settings.
		$cpt_support[] = 'coachings';
		update_option( 'elementor_cpt_support', $cpt_support );
	}
}

// add support link to the WP Toolbar
function visarzo_core_toolbar_link($wp_admin_bar) {
    $args = array(
        'id' => 'support_link',
        'title' => esc_html__('Theme Support & Documentation links','visarzo-core'), 
        'href' => home_url() . '/wp-admin/admin.php?page=envato-theme-license-support', 
        'meta' => array(
            'class' => 'sp_link', 
            'title' => esc_html__('Support','visarzo-core')
            )
    );
    $wp_admin_bar->add_node($args);
}
add_action('admin_bar_menu', 'visarzo_core_toolbar_link', 999);

